@@ -21,7 +21,9 @@
 #define KFILEITEMMODELDIRLISTER_H
 
 #include "dolphin_export.h"
+
 #include <KDirLister>
+
 #include <QUrl>
 
 /**
@@ -34,8 +36,8 @@ class DOLPHIN_EXPORT KFileItemModelDirLister : public KDirLister
     Q_OBJECT
 
 public:
-    KFileItemModelDirLister(QObject* parent = 0);
-    virtual ~KFileItemModelDirLister();
+    explicit KFileItemModelDirLister(QObject* parent = nullptr);
+    ~KFileItemModelDirLister() override;
 
 signals:
     /** Is emitted whenever an error has occurred. */
@@ -48,7 +50,7 @@ signals:
     void urlIsFileError(const QUrl& url);
 
 protected:
-    void handleError(KIO::Job* job) Q_DECL_OVERRIDE;
+    void handleError(KIO::Job* job) override;
 };
 
 #endif
